import { playAudit }  from 'playwright-lighthouse';
import { test, chromium } from '@playwright/test';
import { config as lighthouseDesktopConfig } from "lighthouse/core/config/lr-desktop-config.js";
import { thresholds }  from '../data/thresholdData';

const URLs = [
    "https://www.tatort-game.de/index.html",
    "https://www.swr.de/index.html",
    "https://grochtdreis.de/index.html"
 ]

const options = {
    loglevel: "info",
}

URLs.forEach(url => {
    test.only(`Lighthouse performance test for ${url}`, async () => {
        const browser = await chromium.launch({
            args: ['--remote-debugging-port=9222'],
            headless: true
        });
        const page = await browser.newPage();
        await page.goto(url);
        await playAudit({
            page: page,
            config: lighthouseDesktopConfig,
            thresholds: thresholds,
            port: 9222,
            opts: options,
            reports: {
                formats: {
                    html: true, //defaults to false
                },
                name: `ligthouse-${new Date().toISOString()}`, //defaults to `lighthouse-${new Date().getTime()}`
                directory: `${process.cwd()}/lighthouse`, //defaults to `${process.cwd()}/lighthouse`
            },
        });
        await page.close();
        await browser.close();
    })
});
