const playwright = require('playwright');
const { test,expect} = require('@playwright/test');

test("Screenshot Marketingseite", async({ page }) => {
    await page.goto("https://www.tatort-game.de/index.html");
    await page.screenshot({ path: "screenshots/tatort-game-startseite.png", fullPage: true });
})

test("SWR Startseite", async({ page }) => {
    await page.goto("https://www.swr.de/index.html");
    // Chill until the network is idle
    await page.waitForLoadState('networkidle');
    await page.evaluate(scroll, {direction: "down", speed: "slow"});
    // await page.evaluate(scroll, {direction: "up", speed: "fast"});
    await expect(page).toHaveScreenshot({ path: "screenshots/swr/startseite.png", fullPage: false });
    await expect(page).toHaveScreenshot({ path: "screenshots/swr/startseite-full.png", fullPage: true });
})

test("SWR Logo", async({ page }) => {
    await page.goto("https://www.swr.de/index.html");
    await page.locator('#header-main-navi-header').screenshot({ path: 'screenshots/swr/navbar.png' });
})

test("SWR Logo - multipel", async({ page }) => {
    for (const browserType of [playwright.chromium, playwright.webkit, playwright.firefox]) {
        const browser = await browserType.launch();
        const context = await browser.newContext();
        const page = await context.newPage();
        await page.goto('https://www.swr.de/index.html');
        await page.locator('#header-main-navi-header').screenshot({ path: `screenshots/swr/${browserType.name()}-navbar.png` });
        await browser.close();
      }
})

test("Pagination", async({ page }) => {
    await page.goto("http://localhost:3020/components/preview/pagination--default");
    await page.locator('.pagination').screenshot({ path: 'screenshots/swr/module/pagination/pagination.png' });
})

test("Codepen1", async({page}) => {
    await page.goto("https://000655093.codepen.website/swr-neu/uebersicht-8.html");
    await page.waitForLoadState('networkidle');
    await page.evaluate(scroll, {direction: "down", speed: "fast"});
    await page.evaluate(scroll, {direction: "up", speed: "fast"});
    await expect(page).toHaveScreenshot({ fullPage: true });
})

let scroll = async (args) => {
    const {direction, speed} = args;
    const delay = ms => new Promise(resolve => setTimeout(resolve, ms));
    const scrollHeight = () => document.body.scrollHeight;
    const start = direction === "down" ? 0 : scrollHeight();
    const shouldStop = (position) => direction === "down" ? position > scrollHeight() : position < 0;
    const increment = direction === "down" ? 100 : -100;
    const delayTime = speed === "slow" ? 50 : 10;
    console.error(start, shouldStop(start), increment)
    for (let i = start; !shouldStop(i); i += increment) {
        window.scrollTo(0, i);
        await delay(delayTime);
    }
};